pub enum KtoolError {
InvalidArguments {
tool: &'static str,
source: Error,
},
UnsupportedTool(String),
Classifier(Error),
}Expand description
Failure from the complete in-process Ktool workflow.
Variants
InvalidArguments
The exact operation argument object could not be decoded.
Fields
UnsupportedTool(String)
The requested operation is not one of KTOOLS.
Classifier(Error)
The classifier rejected or could not persist the operation.